import pygame
import random
from typing import Tuple, List

class Food:
    def __init__(self, block_size: int, color: Tuple[int, int, int] = (255, 0, 0)):
        self.block_size = block_size
        self.color = color
        self.position = (0, 0)  # Will be set by spawn()

    def spawn(self, width: int, height: int, occupied_positions: List[Tuple[int, int]]) -> None:
        """
        Spawn food at a random position that isn't occupied by the snake.
        
        Args:
            width: Game area width
            height: Game area height
            occupied_positions: List of positions (typically snake body positions) where food shouldn't spawn
        """
        # Calculate all valid grid positions
        valid_positions = [
            (x, y)
            for x in range(0, width, self.block_size)
            for y in range(0, height, self.block_size)
            if (x, y) not in occupied_positions
        ]
        
        if not valid_positions:
            # No valid positions (snake fills screen) - game should be won
            return
        
        # Choose random position from valid positions
        self.position = random.choice(valid_positions)

    def draw(self, screen: pygame.Surface) -> None:
        """Draw the food on the screen"""
        pygame.draw.rect(
            screen,
            self.color,
            pygame.Rect(
                self.position[0],
                self.position[1],
                self.block_size,
                self.block_size
            )
        )

    def check_collision(self, position: Tuple[int, int]) -> bool:
        """Check if the given position collides with the food"""
        return self.position == position 